@@ -41,6 +41,8 @@
 
 #define KPARTS_DECL_DEPRECATED_TEXT(text) __attribute__ ((__deprecated__(text)))
 
+#define ECM_GENERATEEXPORTHEADER_VERSION_VALUE(major, minor, patch) ((major<<16)|(minor<<8)|(patch))
+
 /* Take any defaults from group settings */
 #if !defined(KPARTS_NO_DEPRECATED) && !defined(KPARTS_DISABLE_DEPRECATED_BEFORE_AND_AT)
 #  ifdef KF_NO_DEPRECATED
@@ -84,7 +86,7 @@
 #define KPARTS_BUILD_DEPRECATED_SINCE(major, minor) 1
 
 #ifdef KPARTS_NO_DEPRECATED
-#  define KPARTS_DISABLE_DEPRECATED_BEFORE_AND_AT 0x57400
+#  define KPARTS_DISABLE_DEPRECATED_BEFORE_AND_AT 0x54300
 #endif
 #ifdef KPARTS_NO_DEPRECATED_WARNINGS
 #  define KPARTS_DEPRECATED_WARNINGS_SINCE 0
@@ -94,7 +96,7 @@
 #  ifdef KPARTS_DISABLE_DEPRECATED_BEFORE_AND_AT
 #    define KPARTS_DEPRECATED_WARNINGS_SINCE KPARTS_DISABLE_DEPRECATED_BEFORE_AND_AT
 #  else
-#    define KPARTS_DEPRECATED_WARNINGS_SINCE 0x57400
+#    define KPARTS_DEPRECATED_WARNINGS_SINCE 0x54300
 #  endif
 #endif
 
@@ -103,7 +105,7 @@
 #endif
 
 #ifdef KPARTS_DEPRECATED
-#  define KPARTS_ENABLE_DEPRECATED_SINCE(major, minor) (((major<<16)|(minor<<8)) > KPARTS_DISABLE_DEPRECATED_BEFORE_AND_AT)
+#  define KPARTS_ENABLE_DEPRECATED_SINCE(major, minor) (ECM_GENERATEEXPORTHEADER_VERSION_VALUE(major, minor, 0) > KPARTS_DISABLE_DEPRECATED_BEFORE_AND_AT)
 #else
 #  define KPARTS_ENABLE_DEPRECATED_SINCE(major, minor) 0
 #endif
@@ -125,77 +127,9 @@
 #else
 #  define KPARTS_DEPRECATED_VERSION_5_0(text)
 #endif
-
-#if KPARTS_DEPRECATED_WARNINGS_SINCE >= 0x54800
-#  define KPARTS_DEPRECATED_VERSION_5_72(text) KPARTS_DECL_DEPRECATED_TEXT(text)
-#else
-#  define KPARTS_DEPRECATED_VERSION_5_72(text)
-#endif
-
-#if KPARTS_DEPRECATED_WARNINGS_SINCE >= 0x54d00
-#  define KPARTS_DEPRECATED_VERSION_5_77(text) KPARTS_DECL_DEPRECATED_TEXT(text)
-#else
-#  define KPARTS_DEPRECATED_VERSION_5_77(text)
-#endif
-
-#if KPARTS_DEPRECATED_WARNINGS_SINCE >= 0x54e00
-#  define KPARTS_DEPRECATED_VERSION_5_78(text) KPARTS_DECL_DEPRECATED_TEXT(text)
-#else
-#  define KPARTS_DEPRECATED_VERSION_5_78(text)
-#endif
-
-#if KPARTS_DEPRECATED_WARNINGS_SINCE >= 0x55000
-#  define KPARTS_DEPRECATED_VERSION_5_80(text) KPARTS_DECL_DEPRECATED_TEXT(text)
-#else
-#  define KPARTS_DEPRECATED_VERSION_5_80(text)
-#endif
-
-#if KPARTS_DEPRECATED_WARNINGS_SINCE >= 0x55100
-#  define KPARTS_DEPRECATED_VERSION_5_81(text) KPARTS_DECL_DEPRECATED_TEXT(text)
-#else
-#  define KPARTS_DEPRECATED_VERSION_5_81(text)
-#endif
-
-#if KPARTS_DEPRECATED_WARNINGS_SINCE >= 0x55200
-#  define KPARTS_DEPRECATED_VERSION_5_82(text) KPARTS_DECL_DEPRECATED_TEXT(text)
-#else
-#  define KPARTS_DEPRECATED_VERSION_5_82(text)
-#endif
-
-#if KPARTS_DEPRECATED_WARNINGS_SINCE >= 0x55300
-#  define KPARTS_DEPRECATED_VERSION_5_83(text) KPARTS_DECL_DEPRECATED_TEXT(text)
-#else
-#  define KPARTS_DEPRECATED_VERSION_5_83(text)
-#endif
-
-#if KPARTS_DEPRECATED_WARNINGS_SINCE >= 0x55800
-#  define KPARTS_DEPRECATED_VERSION_5_88(text) KPARTS_DECL_DEPRECATED_TEXT(text)
-#else
-#  define KPARTS_DEPRECATED_VERSION_5_88(text)
-#endif
-
-#if KPARTS_DEPRECATED_WARNINGS_SINCE >= 0x55a00
-#  define KPARTS_DEPRECATED_VERSION_5_90(text) KPARTS_DECL_DEPRECATED_TEXT(text)
-#else
-#  define KPARTS_DEPRECATED_VERSION_5_90(text)
-#endif
-
-#if KPARTS_DEPRECATED_WARNINGS_SINCE >= 0x56700
-#  define KPARTS_DEPRECATED_VERSION_5_103(text) KPARTS_DECL_DEPRECATED_TEXT(text)
-#else
-#  define KPARTS_DEPRECATED_VERSION_5_103(text)
-#endif
 #define KPARTS_DEPRECATED_VERSION_3(minor, text)      KPARTS_DEPRECATED_VERSION_3_##minor(text)
 #define KPARTS_DEPRECATED_VERSION_4(minor, text)      KPARTS_DEPRECATED_VERSION_4_##minor(text)
 #define KPARTS_DEPRECATED_VERSION_5(minor, text)      KPARTS_DEPRECATED_VERSION_5_##minor(text)
 #define KPARTS_DEPRECATED_VERSION(major, minor, text) KPARTS_DEPRECATED_VERSION_##major(minor, "Since "#major"."#minor". " text)
-#define KPARTS_DEPRECATED_VERSION_BELATED(major, minor, textmajor, textminor, text) KPARTS_DEPRECATED_VERSION_##major(minor, "Since "#textmajor"."#textminor". " text)
-#if defined(__cpp_enumerator_attributes) && __cpp_enumerator_attributes >= 201411
-#  define KPARTS_ENUMERATOR_DEPRECATED_VERSION(major, minor, text) KPARTS_DEPRECATED_VERSION(major, minor, text)
-#  define KPARTS_ENUMERATOR_DEPRECATED_VERSION_BELATED(major, minor, textmajor, textminor, text) KPARTS_DEPRECATED_VERSION_BELATED(major, minor, textmajor, textminor, text)
-#else
-#  define KPARTS_ENUMERATOR_DEPRECATED_VERSION(major, minor, text)
-#  define KPARTS_ENUMERATOR_DEPRECATED_VERSION_BELATED(major, minor, textmajor, textminor, text)
-#endif
 
 #endif /* KPARTS_EXPORT_H */
